@@ -1,10 +1,9 @@
 use std::collections::VecDeque;
-use std::slice::Iter;
-use std::rc::Rc;
-use std::sync::Arc;
-use std::process::ExitStatus;
 use std::iter::{Chain, Iterator, Once};
-use std::vec::IntoIter;
+use std::process::ExitStatus;
+use std::rc::Rc;
+use std::slice::Iter;
+use std::sync::Arc;
 
 use futures::future::join_all;
 
@@ -18,25 +17,25 @@ pub trait Command {
 
 pub type VarArgs = VecDeque<Arc<String>>;
 #[derive(Debug)]
-pub struct ScriptGroup<CommandGeneric : Command> {
+pub struct ScriptGroup<CommandGeneric: Command> {
     pub bail: bool,
     // Enforces that there's always at least 1 script
     pub first: Script<CommandGeneric>,
     pub rest: Vec<Script<CommandGeneric>>,
 }
 
-impl<CommandGeneric : Command> ScriptGroup<CommandGeneric> {
-  fn iter(&self) -> Chain<Once<&Script<CommandGeneric>>, Iter<Script<CommandGeneric>>> {
-    let test =  std::iter::once(&self.first).chain(self.rest.iter());
-    return test;
-  }
+impl<CommandGeneric: Command> ScriptGroup<CommandGeneric> {
+    fn iter(&self) -> Chain<Once<&Script<CommandGeneric>>, Iter<Script<CommandGeneric>>> {
+        let test = std::iter::once(&self.first).chain(self.rest.iter());
+        return test;
+    }
 }
 
 /**
  * TODO: Choose a better name
  */
 #[derive(Debug)]
-pub enum CommandGroup<CommandGeneric : Command> {
+pub enum CommandGroup<CommandGeneric: Command> {
     Parallel(ScriptGroup<CommandGeneric>),
     Series(ScriptGroup<CommandGeneric>),
 }
@@ -49,12 +48,16 @@ fn merge_status(status1: ExitStatus, status2: ExitStatus) -> ExitStatus {
 }
 
 impl<CommandGeneric: Command> CommandGroup<CommandGeneric> {
-    async fn run(&self, parser: &impl ScriptParser<CommandGeneric>, args: VarArgs) -> Result<ExitStatus, ()> {
+    async fn run(
+        &self,
+        parser: &impl ScriptParser<CommandGeneric>,
+        args: VarArgs,
+    ) -> Result<ExitStatus, ()> {
         // TODO: Figure out what to do with args
         match self {
             Self::Parallel(group) => {
                 if group.bail {
-                  println!("Warning: Bail in parallel groups are currently not supported");
+                    println!("Warning: Bail in parallel groups are currently not supported");
                 }
 
                 let mut promises = Vec::<_>::new();
@@ -64,9 +67,9 @@ impl<CommandGeneric: Command> CommandGroup<CommandGeneric> {
                 let mut next = iterator.next();
 
                 while next.is_some() {
-                  promises.push(i.unwrap().run(parser, VecDeque::new()));
-                  i = next;
-                  next = iterator.next();
+                    promises.push(i.unwrap().run(parser, VecDeque::new()));
+                    i = next;
+                    next = iterator.next();
                 }
 
                 promises.push(i.unwrap().run(parser, args));
@@ -75,12 +78,12 @@ impl<CommandGeneric: Command> CommandGroup<CommandGeneric> {
 
                 let mut status = Option::None;
                 for exit_status_result in results {
-                  let exit_status = exit_status_result.unwrap();
-                  if let Some(current_status) = status {
-                    status = Some(merge_status(current_status, exit_status));
-                  } else {
-                    status = Some(exit_status);
-                  }
+                    let exit_status = exit_status_result.unwrap();
+                    if let Some(current_status) = status {
+                        status = Some(merge_status(current_status, exit_status));
+                    } else {
+                        status = Some(exit_status);
+                    }
                 }
 
                 return Ok(status.unwrap());
@@ -93,17 +96,20 @@ impl<CommandGeneric: Command> CommandGroup<CommandGeneric> {
                 let mut final_exit_status: Option<ExitStatus> = Option::None;
 
                 while next.is_some() {
-                  let exit_status = i.unwrap().run(parser, VecDeque::new()).await.unwrap();
-                  if let Some(status) = final_exit_status {
-                    final_exit_status = Some(merge_status(exit_status, status));
-                  } else {
-                    final_exit_status = Some(exit_status);
-                  }
-                  i = next;
-                  next = iterator.next();
+                    let exit_status = i.unwrap().run(parser, VecDeque::new()).await.unwrap();
+                    if let Some(status) = final_exit_status {
+                        final_exit_status = Some(merge_status(exit_status, status));
+                    } else {
+                        final_exit_status = Some(exit_status);
+                    }
+                    i = next;
+                    next = iterator.next();
                 }
 
-                final_exit_status = Some(merge_status(final_exit_status.unwrap(), i.unwrap().run(parser, args).await.unwrap()));
+                final_exit_status = Some(merge_status(
+                    final_exit_status.unwrap(),
+                    i.unwrap().run(parser, args).await.unwrap(),
+                ));
 
                 return Ok(final_exit_status.unwrap());
             }
@@ -121,20 +127,30 @@ pub struct Alias {
  * TODO: Choose a better name
  */
 #[derive(Debug)]
-pub enum Script<CommandGeneric : Command> {
+pub enum Script<CommandGeneric: Command> {
     Command(CommandGeneric),
     Group(Box<CommandGroup<CommandGeneric>>),
     Alias(Alias),
 }
 
-impl<CommandGeneric : Command> Script<CommandGeneric> {
+impl<CommandGeneric: Command> Script<CommandGeneric> {
     #[async_recursion(?Send)]
-    pub async fn run(&self, parser: &impl ScriptParser<CommandGeneric>, args: VarArgs) -> Result<ExitStatus, ()> {
+    pub async fn run(
+        &self,
+        parser: &impl ScriptParser<CommandGeneric>,
+        args: VarArgs,
+    ) -> Result<ExitStatus, ()> {
         match self {
             Script::Command(cmd) => cmd.run(args).await,
             Script::Group(group) => group.run(parser, args).await,
             Script::Alias(alias) => {
-              let joined_args: VecDeque<Arc<String>> = alias.args.iter().into_iter().map(|arg| arg.clone()).chain(args.into_iter()).collect();
+                let joined_args: VecDeque<Arc<String>> = alias
+                    .args
+                    .iter()
+                    .into_iter()
+                    .map(|arg| arg.clone())
+                    .chain(args.into_iter())
+                    .collect();
 
                 parser
                     .parse(alias.task.as_str())
@@ -146,6 +162,6 @@ impl<CommandGeneric : Command> Script<CommandGeneric> {
     }
 }
 
-pub trait ScriptParser<CommandGeneric : Command> {
+pub trait ScriptParser<CommandGeneric: Command> {
     fn parse(&self, task: &str) -> Result<Rc<Script<CommandGeneric>>, ()>;
 }
